package cokr.xit.fims.epst.dao;

import java.util.List;
import java.util.Map;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import cokr.xit.foundation.component.AbstractMapper;
import cokr.xit.foundation.data.DataObject;

import cokr.xit.fims.epst.EpostRcptReg;
import cokr.xit.fims.epst.EpostQuery;

/** 전자우편 접수 등록 정보 DAO
 *
 * <p>상세 설명:
 *
 * <pre>
 * ============ 변경 이력 ============
 * 2023-10-11	JoJH 최초 작성
 * ================================
 * </pre>
 */
@Mapper("epostRcptRegMapper")
public interface EpostRcptRegMapper extends AbstractMapper {

	/**지정한 조건에 따라 전자우편 접수 등록 목록을 조회하여 반환한다.<br />
	 * @param req 전자우편 조회 조건
	 * @return 전자우편 접수 등록 목록
	 */
	List<DataObject> selectEpostRcptRegList(EpostQuery req);

	/**지정한 조건에 따라 전자우편 접수 등록 객체들을 반환한다.
	 * @param req 전자우편 조회 조건
	 * @return 전자우편 접수 등록 객체 목록
	 */
	List<DataObject> selectEpostRcptRegs(EpostQuery req);

	/**지정한 조건에 따라 부과제외 대장 객체의 마지막 1개를 반환한다.
	 * @param levyExclId 부과제외 ID
	 * @return 부과제외 대장 객체
	 */
	default DataObject selectEpostRcptRegInfo(EpostQuery req) {
		// 사용 여부
		if (req.getUseYn() == null) {
			req.setUseYn("Y");
		}
		// 기본 정렬
		if (req.getOrderBy() == null) {
			req.setOrderBy("ERR.CON_KEY DESC");
		}

		List<DataObject> epostRcptReg = selectEpostRcptRegs(req);

		return !epostRcptReg.isEmpty() ? epostRcptReg.get(0) : null;
	}

	/**지정한 조건에 따라 전자우편 발송 상태 정보를 반환한다.
	 * @param req 전자우편 접수 등록 조회 조건
	 * @return 전자우편 발송 상태 객체 정보
	 */
	List<DataObject> selectEpostRcptRegDtlList(EpostQuery req);

	/**지정한 조건에 따라 전자우편 접수 등록 목록을 조회하여 반환한다.<br />
	 * @param req 전자우편 조회 조건
	 * @return 전자우편 접수 등록 목록
	 */
	String selectEpostSenderRegSeq(String conKey);

	/** <br />
	 * @param req 전자우편 조회 조건
	 * @return 전자우편 접수 등록 목록
	 */
	String selectEpostRgNo(String sggCd, String taskSeCd);

	/**<br />
	 * @param req 전자우편 조회 조건
	 * @return 전자우편 접수 등록 목록
	 */
	DataObject selectDeptSggInfo(String deptCd);

	/**전자우편 접수 등록 정보를 등록한다.
	 * @param params 파라미터
	 * <ul><li>"epostRcptReg" - 전자우편 접수 등록</li>
	 *     <li>"currentUser" - 현재 접속한 사용자</li>
	 * </ul>
	 * @return 저장된 정보수
	 */
	int insertEpostRcptReg(Map<String, Object> params);

	/**전자우편 접수 등록 정보를 등록한다.
	 * @param epostRcptReg 전자우편 접수 등록
	 * @return 저장 여부
	 * <ul><li>저장됐으면 true</li>
	 *     <li>그렇지 않으면 false</li>
	 * </ul>
	 */
	default boolean insert(EpostRcptReg epostRcptReg) {
		return epostRcptReg != null && insertEpostRcptReg(params().set("epostRcptReg", epostRcptReg)) == 1;
	}

	/**전자우편 접수 등록 정보를 수정한다.
	 * @param params 파라미터
	 * <ul><li>"epostRcptReg" - 전자우편 접수 등록</li>
	 *     <li>"currentUser" - 현재 접속한 사용자</li>
	 * </ul>
	 * @return 저장된 정보수
	 */
	int updateEpostRcptReg(Map<String, Object> params);

	/**전자우편 접수 등록 정보를 수정한다.
	 * @param epostRcptReg 전자우편 접수 등록
	 * @return 저장 여부
	 * <ul><li>저장됐으면 true</li>
	 *     <li>그렇지 않으면 false</li>
	 * </ul>
	 */
	default boolean update(EpostRcptReg epostRcptReg) {
		return epostRcptReg != null && updateEpostRcptReg(params().set("epostRcptReg", epostRcptReg)) == 1;
	}

	/**전자우편 접수 등록 정보의 우편 처리 상태 코드를 수정한다.
	 * @param params 파라미터
	 * <ul><li>"epostRcptReg" - 전자우편 접수 등록</li>
	 *     <li>"currentUser" - 현재 접속한 사용자</li>
	 * </ul>
	 * @return 저장된 정보수
	 */
	int updatePostPrcsSttsCd(EpostRcptReg epostRcptReg);

	/**지정한 전자우편 접수 등록을 삭제한다.
	 * @param params 파라미터
	 * <ul><li>"epostRcptReg" - 전자우편 접수 등록</li>
	 *     <li>"currentUser" - 현재 접속한 사용자</li>
	 * </ul>
	 * @return 저장된 정보수
	 */
	int deleteEpostRcptReg(EpostRcptReg epostRcptReg);

}
